==> cscec5b-sync-impl-3.0.0-20201225.082625-18-sources.jar: com/ejianc/business/sync/service/impl/ImgprogService.java <==
package com.ejianc.business.sync.service.impl;

import com.ejianc.business.sync.bean.Imgprog;
import com.ejianc.business.sync.bean.Imgprogb;
import com.ejianc.business.sync.cons.ModelCodeCons;
import com.ejianc.business.sync.mapper.ImgprogMapper;
import com.ejianc.business.sync.service.IImgprogService;
import com.ejianc.business.sync.service.IImgprogbService;
import com.ejianc.business.sync.vo.SumGrapDetailVO;
import com.ejianc.business.sync.vo.SumGrapVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service("imgprogService")
public class ImgprogService extends BaseServiceImpl<ImgprogMapper, Imgprog> implements IImgprogService {
    private Logger logger = LoggerFactory.getLogger(ImgprogService.class);

    @Autowired
    private IImgprogbService imgprogbService;

    @Autowired
    private SessionManager sessionManager;

    @Override
    public CommonResponse<String> syncImg(SumGrapVO sumGrapVO) {
        Long id = sumGrapVO.getId();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm");
        String ts = sdf.format(new Date());
        // 形象进度主表
        Imgprog entity = new Imgprog();
        entity.setPkImgprog(ModelCodeCons.NC_JD + id);
        entity.setCsrcId(ModelCodeCons.NC_JD + id);
        entity.setvBillCode(sumGrapVO.getBillCode());
        entity.setPkProject(sumGrapVO.getProjectSourceId());
        entity.setPkCorp(sumGrapVO.getCropSourceId());
        entity.setPkContract(sumGrapVO.getContractId());
        entity.setPeriod(sumGrapVO.getSumMonth());
        entity.setReportPerson(sessionManager.getUserContext().getUserName());
        entity.setnConfirmMny(sumGrapVO.getSumApproveMny());
        entity.setBisSettle("N");
        entity.setCsrcbId("");
        entity.setTs(ts);
        // 形象进度子表
        List<SumGrapDetailVO> detailList = sumGrapVO.getDetailList();
        List<Imgprogb> list = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(detailList)){
            for(SumGrapDetailVO detai : detailList){
                if(detai.getLeafFlag() == 0){
                    Imgprogb vo = new Imgprogb();
                    vo.setPkImgprogb(ModelCodeCons.NC_JD + detai.getId());
                    vo.setCsrcbId(ModelCodeCons.NC_JD + detai.getId());
                    vo.setPkImgprog(ModelCodeCons.NC_JD + id);
                    vo.setCsrcId(ModelCodeCons.NC_JD + id);
                    vo.setPkSublist(detai.getInfoId());
                    vo.setNthisfinishnum(detai.getApproveNum());
                    vo.setNthisfinishoriginmny(detai.getApproveMny());
                    vo.setNprice(detai.getPrice());
                    vo.setBisSettle("N");
                    vo.setTs(ts);
                    list.add(vo);
                }
            }
        }
        entity.setDetailList(list);
        try {
            baseMapper.insertImgprog(entity);
            if(CollectionUtils.isNotEmpty(list)){
                for(Imgprogb imgprogb : list){
                    imgprogbService.batchInsert(imgprogb);
                }
            }
            logger.info("imgprog插入完毕:" + entity);
        } catch (Exception e) {
            logger.error(e.toString());
            return CommonResponse.error("形象进度插入NC库失败");
        }
        return CommonResponse.success("同步成功！");
    }

    @Override
    public CommonResponse<String> delSyncImg(Long id) {
        baseMapper.delSyncImg(ModelCodeCons.NC_JD + id);
        baseMapper.delSyncImgB(ModelCodeCons.NC_JD + id);
        return CommonResponse.success("删除成功！");
    }

    @Override
    public List selectStatus(Integer day) {
        return baseMapper.selectStatus(day);
    }

    @Override
    public List getSyncImgList() {
        return baseMapper.getSyncImgList();
    }

    /**
     * 查看数据有没有被同步
     * @param id
     * @return
     */
    @Override
    public Integer getSyncImg(Long id) {
        return baseMapper.getSyncImg(ModelCodeCons.NC_JD + id);
    }

}

==> cscec5b-sync-impl-3.0.0-20201225.123140-25-sources.jar: com/ejianc/business/sync/service/impl/ImgprogService.java <==
package com.ejianc.business.sync.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.ejianc.business.sync.bean.Imgprog;
import com.ejianc.business.sync.bean.Imgprogb;
import com.ejianc.business.sync.cons.ModelCodeCons;
import com.ejianc.business.sync.mapper.ImgprogMapper;
import com.ejianc.business.sync.service.IImgprogService;
import com.ejianc.business.sync.service.IImgprogbService;
import com.ejianc.business.sync.vo.SumGrapDetailVO;
import com.ejianc.business.sync.vo.SumGrapVO;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.template.BaseServiceImpl;
import org.apache.commons.collections.CollectionUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Service("imgprogService")
public class ImgprogService extends BaseServiceImpl<ImgprogMapper, Imgprog> implements IImgprogService {
    private Logger logger = LoggerFactory.getLogger(ImgprogService.class);

    @Autowired
    private IImgprogbService imgprogbService;

    @Autowired
    private SessionManager sessionManager;

    @Override
    public CommonResponse<String> syncImg(SumGrapVO sumGrapVO) {
        Long id = sumGrapVO.getId();
        SimpleDateFormat sdf = new SimpleDateFormat("yyyy-MM-dd HH:mm");
        String ts = sdf.format(new Date());
        // 形象进度主表
        Imgprog entity = new Imgprog();
        entity.setPkImgprog(ModelCodeCons.NC_JD + id);
        entity.setCsrcId(ModelCodeCons.NC_JD + id);
        entity.setvBillCode(sumGrapVO.getBillCode());
        entity.setPkProject(sumGrapVO.getProjectSourceId());
        entity.setPkCorp(sumGrapVO.getCropSourceId());
        entity.setPkContract(sumGrapVO.getContractId());
        entity.setPeriod(sumGrapVO.getSumMonth());
        entity.setReportPerson(sessionManager.getUserContext().getUserName());
        entity.setnConfirmMny(sumGrapVO.getSumApproveMny());
        entity.setBisSettle("N");
        entity.setCsrcbId("");
        entity.setTs(ts);
        // 形象进度子表
        List<SumGrapDetailVO> detailList = sumGrapVO.getDetailList();
        List<Imgprogb> list = new ArrayList<>();
        if(CollectionUtils.isNotEmpty(detailList)){
            for(SumGrapDetailVO detai : detailList){
                if(detai.getLeafFlag() == 0){
                    Imgprogb vo = new Imgprogb();
                    vo.setPkImgprogb(ModelCodeCons.NC_JD + detai.getId());
                    vo.setCsrcbId(ModelCodeCons.NC_JD + detai.getId());
                    vo.setPkImgprog(ModelCodeCons.NC_JD + id);
                    vo.setCsrcId(ModelCodeCons.NC_JD + id);
                    vo.setPkSublist(detai.getInfoId());
                    vo.setNthisfinishnum(detai.getApproveNum());
                    vo.setNthisfinishoriginmny(detai.getApproveMny());
                    vo.setNprice(detai.getPrice());
                    vo.setBisSettle("N");
                    vo.setTs(ts);
                    list.add(vo);
                }
            }
        }
        entity.setDetailList(list);
        try {
            baseMapper.insertImgprog(entity);
            if(CollectionUtils.isNotEmpty(list)){
                for(Imgprogb imgprogb : list){
                    imgprogbService.batchInsert(imgprogb);
                }
            }
            logger.info("imgprog插入完毕:" + JSONObject.toJSONString(entity));
        } catch (Exception e) {
            logger.error(e.toString());
            return CommonResponse.error("形象进度插入NC库失败");
        }
        return CommonResponse.success("同步成功！");
    }

    @Override
    public CommonResponse<String> delSyncImg(Long id) {
        baseMapper.delSyncImg(ModelCodeCons.NC_JD + id);
        baseMapper.delSyncImgB(ModelCodeCons.NC_JD + id);
        return CommonResponse.success("删除成功！");
    }

    @Override
    public List selectStatus(Integer day) {
        return baseMapper.selectStatus(day);
    }

    @Override
    public List getSyncImgList() {
        return baseMapper.getSyncImgList();
    }

    /**
     * 查看数据有没有被同步
     * @param id
     * @return
     */
    @Override
    public Integer getSyncImg(Long id) {
        return baseMapper.getSyncImg(ModelCodeCons.NC_JD + id);
    }

}
